@@ -11,6 +11,7 @@
 #include "stringutil.h"
 #include "sortutil.h"
 
+#include <KItinerary/BoatTrip>
 #include <KItinerary/BusTrip>
 #include <KItinerary/Event>
 #include <KItinerary/Flight>
@@ -33,6 +34,8 @@
 #include <QVariant>
 
 #include <cmath>
+#include <cstring>
+#include <set>
 
 using namespace KItinerary;
 
@@ -68,6 +71,7 @@ static bool prefixConflictIfPresent(const T &lhs, const T &rhs)
 static bool isSameFlight(const Flight &lhs, const Flight &rhs);
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs);
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs);
+static bool isSameBoatTrip(const BoatTrip &lhs, const BoatTrip &rhs);
 static bool isSameLodingBusiness(const LodgingBusiness &lhs, const LodgingBusiness &rhs);
 static bool isSameFoodEstablishment(const FoodEstablishment &lhs, const FoodEstablishment &rhs);
 static bool isSameTouristAttractionVisit(const TouristAttractionVisit &lhs, const TouristAttractionVisit &rhs);
@@ -177,6 +181,21 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         return isSameBusTrip(lhsTrip, rhsTrip);
     }
 
+    // boat
+    if (JsonLd::isA<BoatReservation>(lhs)) {
+        const auto lhsRes = lhs.value<BoatReservation>();
+        const auto rhsRes = rhs.value<BoatReservation>();
+        if (lhsRes.reservationNumber() != rhsRes.reservationNumber()) {
+            return false;
+        }
+        return isSame(lhsRes.reservationFor(), rhsRes.reservationFor());
+    }
+    if (JsonLd::isA<BoatTrip>(lhs)) {
+        const auto lhsTrip = lhs.value<BoatTrip>();
+        const auto rhsTrip = rhs.value<BoatTrip>();
+        return isSameBoatTrip(lhsTrip, rhsTrip);
+    }
+
     // hotel: booking ref, checkin day, name match
     if (JsonLd::isA<LodgingReservation>(lhs)) {
         const auto lhsRes = lhs.value<LodgingReservation>();
@@ -391,6 +410,13 @@ static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs)
     return lhs.busName() == rhs.busName() && lhs.busNumber() == rhs.busNumber() && lhs.departureTime() == rhs.departureTime();
 }
 
+static bool isSameBoatTrip(const BoatTrip& lhs, const BoatTrip& rhs)
+{
+    return lhs.departureTime() == rhs.departureTime()
+        && LocationUtil::isSameLocation(lhs.departureBoatTerminal(), rhs.departureBoatTerminal())
+        && LocationUtil::isSameLocation(lhs.arrivalBoatTerminal(), rhs.arrivalBoatTerminal());
+}
+
 static bool isSameLodingBusiness(const LodgingBusiness &lhs, const LodgingBusiness &rhs)
 {
     if (lhs.name().isEmpty() || rhs.name().isEmpty()) {
@@ -536,12 +562,48 @@ static Person mergeValue(const Person &lhs, const Person &rhs)
     return p;
 }
 
+static QVariantList mergeSubjectOf(const QVariantList &lhs, const QVariantList &rhs)
+{
+    std::set<QString> mergedSet;
+    for (const auto &v : lhs) {
+        if (v.type() != QVariant::String) {
+            return rhs.isEmpty() ? lhs : rhs;
+        }
+        mergedSet.insert(v.toString());
+    }
+    for (const auto &v : rhs) {
+        if (v.type() != QVariant::String) {
+            return rhs.isEmpty() ? lhs : rhs;
+        }
+        mergedSet.insert(v.toString());
+    }
+
+    QVariantList result;
+    result.reserve(mergedSet.size());
+    std::copy(mergedSet.begin(), mergedSet.end(), std::back_inserter(result));
+    return result;
+}
+
+static int ticketTokenSize(const QVariant &v)
+{
+    if (v.type() == QVariant::String) {
+        return v.toString().size();
+    }
+    if (v.type() == QVariant::ByteArray) {
+        return v.toByteArray().size();
+    }
+    return 0;
+}
+
 static Ticket mergeValue(const Ticket &lhs, const Ticket &rhs)
 {
     auto t = JsonLdDocument::apply(lhs, rhs).value<Ticket>();
     // prefer barcode ticket tokens over URLs
     if (t.ticketTokenType() == Token::Url && lhs.ticketTokenType() != Token::Url && lhs.ticketTokenType() != Token::Unknown) {
         t.setTicketToken(lhs.ticketToken());
+    } else if (lhs.ticketTokenType() != Token::Url && rhs.ticketTokenType() != Token::Url
+            && lhs.ticketTokenType() != Token::Unknown && rhs.ticketTokenType() != Token::Unknown) {
+        t.setTicketToken(ticketTokenSize(lhs.ticketTokenData()) > ticketTokenSize(rhs.ticketTokenData()) ? lhs.ticketToken() : rhs.ticketToken());
     }
     return t;
 }
@@ -591,6 +653,10 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
             rv = mergeValue(lv.value<Ticket>(), rv.value<Ticket>());
         } else if ((metaType.flags() & QMetaType::IsGadget) && metaType.metaObject()) {
             rv = merge(prop.readOnGadget(lhs.constData()), rv);
+        } else if (mt == QVariant::List && std::strcmp(prop.name(), "subjectOf") == 0) {
+            rv = mergeSubjectOf(lv.toList(), rv.toList());
+        } else if (mt == QVariant::String) {
+            rv = StringUtil::betterString(lv.toString(), rv.toString()).toString();
         }
 
         if (!JsonLd::valueIsNull(rv)) {
