@@ -137,8 +137,10 @@ static constexpr const struct {
     { "fahrkarte", Rct2Ticket::Transport },
     { "fahrschein", Rct2Ticket::Transport },
     { "cestovny listok", Rct2Ticket::Transport },
+    { "jizdenka", Rct2Ticket::Transport },
     { "reservation", Rct2Ticket::Reservation },
     { "reservierung", Rct2Ticket::Reservation },
+    { "interrail", Rct2Ticket::RailPass },
 };
 
 Rct2Ticket::Type Rct2Ticket::type() const
@@ -161,11 +163,25 @@ Rct2Ticket::Type Rct2Ticket::type() const
         }
     }
 
+    // alternatively, check all fields covering the title area, for even more creative placements...
+    for (const auto &f : d->layout.fields(0, 14, 38, 2)) {
+        for (auto it = std::begin(rct2_ticket_type_map); it != std::end(rct2_ticket_type_map); ++it) {
+            if (f.text().toCaseFolded().contains(QLatin1String(it->name))) {
+                return it->type;
+            }
+        }
+    }
+
     return Unknown;
 }
 
 QString Rct2Ticket::title() const
 {
+    // RPT has shorter title fields
+    if (type() == Rct2Ticket::RailPass) {
+        return d->layout.text(0, 18, 19, 1);
+    }
+
     // somewhat standard compliant layout
     if (d->layout.text(0, 15, 3, 1).trimmed().isEmpty()) {
         return d->layout.text(0, 18, 33, 1).trimmed();
@@ -200,12 +216,13 @@ static QString rct2Clean(const QString &s)
 
 QString Rct2Ticket::outboundDepartureStation() const
 {
-    return rct2Clean(d->layout.text(6, 13, 17, 1).trimmed());
+    // 6, 13, 17, 1 would be according to spec, but why stick to that...
+    return type() != RailPass ? rct2Clean(d->layout.text(6, 12, 18, 1).trimmed()) : QString();
 }
 
 QString Rct2Ticket::outboundArrivalStation() const
 {
-    return rct2Clean(d->layout.text(6, 34, 17, 1).trimmed());
+    return type() != RailPass ? rct2Clean(d->layout.text(6, 34, 17, 1).trimmed()) : QString();
 }
 
 QString Rct2Ticket::outboundClass() const
@@ -225,12 +242,13 @@ QDateTime Rct2Ticket::returnArrivalTime() const
 
 QString Rct2Ticket::returnDepartureStation() const
 {
-    return rct2Clean(d->layout.text(7, 13, 17, 1).trimmed());
+    // 7, 13, 17, 1 would be according to spec, but you can guess by now how well that is followed...
+    return type() != RailPass ? rct2Clean(d->layout.text(7, 12, 18, 1).trimmed()) : QString();
 }
 
 QString Rct2Ticket::returnArrivalStation() const
 {
-    return rct2Clean(d->layout.text(7, 34, 17, 1).trimmed());
+    return type() != RailPass ? rct2Clean(d->layout.text(7, 34, 17, 1).trimmed()) : QString();
 }
 
 QString Rct2Ticket::returnClass() const
